@@ -5,10 +5,13 @@ __all__ = ['googleplus_download']
 from ..common import *
 
 def googleplus_download(url, output_dir = '.', merge = True, info_only = False):
+    # Percent-encoding Unicode URL
+    url = parse.quote(url, safe = ':/')
+    
     html = get_html(url)
     html = parse.unquote(html).replace('\/', '/')
     
-    title = r1(r'<title>(.*)\n', html)
+    title = r1(r'<title>(.*)</title>', html) or r1(r'<title>(.*)\n', html)
     
     url2 = r1(r'"(https\://plus\.google\.com/photos/.*?)",,"image/jpeg","video"\]', html)
     html2 = get_html(url2)
